@@ -95,7 +95,7 @@ static GOptionEntry entries[] = {
 	  N_("Force a module to be used for extraction (e.g. “foo” for “foo.so”)"),
 	  N_("MODULE") },
 	{ "output-format", 'o', 0, G_OPTION_ARG_STRING, &output_format_name,
-	  N_("Output results format: “sparql”, or “turtle”"),
+	  N_("Output results format: “sparql”, “turtle” or “json-ld”"),
 	  N_("FORMAT") },
 	{ "domain-ontology", 'd', 0,
 	  G_OPTION_ARG_STRING, &domain_ontology_name,
@@ -364,6 +364,12 @@ main (int argc, char *argv[])
 	g_option_context_add_main_entries (context, entries, NULL);
 	g_option_context_parse (context, &argc, &argv, &error);
 
+	if (error) {
+		g_printerr ("%s\n", error->message);
+		g_error_free (error);
+		return EXIT_FAILURE;
+	}
+
 	if (!filename && mime_type) {
 		gchar *help;
 
